==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/cl/iclshell.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICLSHELL_H
#define ICLSHELL_H

//
//  A shell based on command line interface
//
#include "ishell.h"


class iclCommandInterpreter;


class iclShell : public iShell
{

	friend class iShellFactory;

public:

	virtual void Exit();

	virtual bool LoadShellStateFromFile(iFile &F);
	virtual bool SaveShellStateToFile(iFile &F) const;

#ifdef I_DEBUG
	virtual void OutputDebugMessage(const iString &message) const;
#endif

protected:

	iclShell(int argc, char **argv);
	virtual ~iclShell();

	virtual void ConstructorBody();  
	virtual void DestructorBody();  

	virtual void Start();
	virtual void RunBody();
	virtual void PrepareForConstruction();
	virtual void DefineSpecificCommandLineOptions();
	virtual void LoadStateFile(const iString &fname);
	virtual void OutputStartupMessage(const iString &message);
	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o);

	iclCommandInterpreter *mInterpreter;
	bool mContinue;
};

#endif  // ICLSHELL_H

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/shells/cl/iclshell.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef ICLSHELL_H
#define ICLSHELL_H

//
//  A shell based on command line interface
//
#include "ishell.h"


class iclCommandInterpreter;


class iclShell : public iShell
{

	friend class iShellFactory;

public:

	vtkTypeMacro(iclShell,iShell);

	virtual void Exit();

protected:

	iclShell(int argc, char **argv);
	virtual ~iclShell();

	virtual void ConstructorBody();  
	virtual void DestructorBody();  

	virtual void Start();
	virtual void RunBody();
	virtual void PrepareForConstruction();
	virtual void PrepareToLoadStateFile();
	virtual bool LoadShellStateFromFileBody(iFile &F);
	virtual bool SaveShellStateToFileBody(iFile &F) const;
	virtual void DefineSpecificCommandLineOptions();
	virtual bool AnalyseOneExtendedCommandLineOption(const struct Option &o);

	iclCommandInterpreter *mInterpreter;
	bool mContinue;
};

#endif  // ICLSHELL_H
